
--------------------------------------
-- Namespaces
--------------------------------------
local _, core = ...;
core.Config = {}; -- adds Config table to addon namespace
ZishorRaidResetDB = {}
ZishorRaidResetTimers = {}
ZishorRaidResetTimersAdaption = {}
local Config = core.Config;
local UIConfig, menu, UIConfigToons;
local UIText, MCText, ONYText, BWLText, ZGText, INFOText, INFOTextID, nextAvailableMC, nextAvailableOny, nextAvailableZG, nextAvailableBWL, nextAvailableAQ20, nextAvailableAQ40,
MCTextAlts, BWLTextAlts, ZGTextAlts, OnyTextAlts, AQ20TextAlts, AQ40TextAlts ,NoToonsWithID, AQ20Text, AQ40Text, AQ20TextAlts, AQ40TextAlts;
local timerMC, timerOny, timerBWL, timerZG, timerAQ20, timerAQ40;
local OnyResetDate, ZGResetDate, MCBWLResetDate;
local bHelper;
local bLoginHelper = false;
local loginTime = 0;
--------------------------------------
-- Defaults 
--------------------------------------
local classColors = {
	{r = 0.78, g = 0.61, b = 0.43},--1 Warrior
	{r = 0.96, g = 0.55, b = 0.73},--2 Paladin
	{r = 0.67, g = 0.83, b = 0.45},--3 Hunter
	{r = 1, g = 0.96, b = 0.41},--4 Rogue
	{r = 1, g = 1, b = 1},--5 Priest
	{r = 0, g = 0, b = 0},--6 Death Knight
	{r = 0.0, g = 0.55, b = 0.87},--7 Shaman
	{r = 0.41, g = 0.80, b = 0.94},--8 Mage
	{r = 0.58, g = 0.51, b = 0.79},--9 Warlock
	{r = 0, g = 0, b = 0},--10 Monk
	{r = 1, g = 0.49, b = 0.04}--11 Druide
}

local defaults = {
	theme = {
		r = 0, 
		g = 0.8, -- 204/255
		b = 1,
		hex = "00ccff"
	}
}

ZishorToonRaidResetTimers = {}

local raidNames ={
"Onyxia's Lair", 
"Blackwing Lair", 
"Molten Core", 
"Zul'Gurub", 
"Ruins of Ahn'Qiraj", 
 "Ahn'Qiraj Temple",
"Naxxramas",
 "Onyxias Hort",
 "Pechschwingenhort",
 "Geschmolzener Kern",
 "Ruinen von Ahn'Qiraj",
 "Tempel von Ahn'Qiraj", 
}
-- Config functions
--------------------------------------

function Config:GetThemeColor()
	local c = defaults.theme;
	return c.r, c.g, c.b, c.hex;
end

function Config:FrameUpdateHandler()
	
		if menu:IsShown() == true then
			--close frame without Timer update
			menu:SetShown(false)
		else
			if UIConfigToons == nil or UIConfigToons:IsShown() == false then
				--Update Timer b4 open the frame			
				Config:UpdateFrame();
				menu:SetShown(true)	
			else
			
			end
		end
end

function Config:CheckTimers()

--initial Timers
MCBWLResetDate = time{year=2020, month=5, day=06, hour=09, minute=00}
OnyResetDate  = time{year=2020, month=5, day=03, hour=09, minute=00}
ZGResetDate = time{year=2020, month=5, day=01, hour=09, minute=00}

actualTime = time()

--fill database values to schedule and reschedule reset timers
ZishorRaidResetTimersAdaption[1] = 604800; --1 week 
ZishorRaidResetTimersAdaption[2] = 432000; --5 days
ZishorRaidResetTimersAdaption[3] = 259200; --3 days

	if next(ZishorRaidResetTimers) == nil then
		--fill database with inital values if its loaded the first time
		ZishorRaidResetTimers[1] = MCBWLResetDate
		ZishorRaidResetTimers[2] = OnyResetDate
		ZishorRaidResetTimers[3] = ZGResetDate

	end
	for i = 1, 3 do 
		if (ZishorRaidResetTimers[i] < actualTime) then
			for j = 1, 366 do 
				--if the actual time is after the old reset timer, we have to reschedule the reset timer, till its fine.
				--We can recalculate it from May 2020 1 year ahead. 
				ZishorRaidResetTimers[i] = ZishorRaidResetTimers[i] + ZishorRaidResetTimersAdaption[i]
				if (ZishorRaidResetTimers[i] > actualTime) then
					break;
				end
			
			end
			
		end


	end


end

function Config:UpdateRaidTimersWithID(name, timer)

numberOfDays = (timer / 86400);
numberOfHours = ((timer % 86400 ) / 3600) ;
numberOfMinutes = (((timer % 86400 ) % 3600 ) / 60)

if numberOfDays < 1 then		 
	numberOfHours =  math.floor(numberOfHours+0.0)
	numberOfMinutes =  math.floor(numberOfMinutes+0.0)
	_G[name]:SetText(numberOfHours .. " hrs " .. numberOfMinutes .. " mins")
 else
	if numberOfHours < 1 then
		numberOfDays =  math.floor(numberOfDays+0.0)
		numberOfHours =  math.floor(numberOfHours+0.0)
		numberOfMinutes =  math.floor(numberOfMinutes+0.0)
		_G[name]:SetText(numberOfDays .. " days " .. numberOfMinutes .. " mins")			
	else
		numberOfDays =  math.floor(numberOfDays+0.0)
		numberOfHours =  math.floor(numberOfHours+0.0)
		numberOfMinutes =  math.floor(numberOfMinutes+0.0)
		_G[name]:SetText(numberOfDays .. " days " .. numberOfHours .. " hrs")
	end
end

end
function Config:UpdateFrame()
	--Checks the timers of all raids if they are right, adjusts them if needed and store them in the DB
	Config:CheckTimers()
	
	--Before we update all timer we set everything to no, because we first check if IDs are there and then we handle the raids with no ID
	Config:NoIDsExisting()
	
	for i = 1 , 4 do
	name, id, reset = GetSavedInstanceInfo(i)
		if name == nil and i == 1 then 
			-- if the first entry is nil no IDs are existing, so we can exit the for loop
			Config:CheckForNoId();
			Config:FillToonsDB();
			return;
	
		else	
			if raidNames[1] == name  or raidNames[8] == name then
			-----------Ony-------------- 
			 timerOny:SetText("Yes")	
			 self:UpdateRaidTimersWithID("TimerOny", reset)
			end
		
			if raidNames[2] == name or raidNames[9] == name then
			----------BWL--------------
			 timerBWL:SetText("Yes")
			 self:UpdateRaidTimersWithID("TimerBWL", reset)
			end
			
			if raidNames[3] == name or raidNames[10] == name then
			-----------MC--------------
			 timerMC:SetText("Yes")
			 self:UpdateRaidTimersWithID("TimerMC", reset)	
			end
			if raidNames[4] == name then
			-----------ZG--------------
			 timerZG:SetText("Yes")
			self:UpdateRaidTimersWithID("TimerZG", reset)
			end
			if raidNames[5] == name or raidNames[11] == name then
			-----------AQ20--------------
				timerAQ20:SetText("Yes")
				self:UpdateRaidTimersWithID("TimerAQ20", reset)
			end
			if raidNames[6] == name or raidNames[12] == name then
			-----------AQ40--------------
				timerAQ40:SetText("Yes")
				self:UpdateRaidTimersWithID("TimerAQ40", reset)
			end
			
		end
		
	end
	
	--Now adapt every raid where we dont have an ID
	Config:CheckForNoId();

	--Now we enter our informations form this method in a DB 
	Config:FillToonsDB();
	
	--To know when the reset was is not the problem, but maybe there was already a f.ee ZG reset and he cleared it only hours after the reset. Its basicly not predictable
	

end
function Config:FillToonsDB()

	--Only lvl 60er Toons should be stored
	if UnitLevel("player") < 60 then return end;
	
	_, _, classIndex = UnitClass("player");
	bEntryFound = false;
	local entryFoundIndex;
	if  next(ZishorToonRaidResetTimers) == nil then
		--if there are no entries we can fill the DB without checking anything
		ids = self:ToonsID();
		ZishorToonRaidResetTimers[1] = { name = UnitName("player"), level = UnitLevel("player"), raidIDs = ids, classID = classIndex}
	else
		--Look if there is already an entry with our name, if so overwrite the ids.
		for i = 1, Config:getTableLength(ZishorToonRaidResetTimers) do
			if ZishorToonRaidResetTimers[i].name ==  UnitName("player") then bEntryFound = true entryFoundIndex = i end
		end
		if bEntryFound then
			ids = self:ToonsID();
			ZishorToonRaidResetTimers[entryFoundIndex].raidIDs = ids;
		else
			ids = self:ToonsID();
			ZishorToonRaidResetTimers[Config:getTableLength(ZishorToonRaidResetTimers) + 1] = { name = UnitName("player"), level = UnitLevel("player"), raidIDs = ids, classID = classIndex}
		end
	end
	
end

function Config:ToonsID()
	local ids = {}
	ids[1] = timerMC:GetText();
	ids[2] = timerOny:GetText();
	ids[3] = timerBWL:GetText();
	ids[4] = timerZG:GetText();
	ids[5] = timerAQ20:GetText();
	ids[6] = timerAQ40:GetText();
	return ids;
end

function Config:UpdateRaidTimersWithOutID(name, timer)

numberOfDays = (timer / 86400);
numberOfHours = (((timer) % 86400 ) / 3600) ;
numberOfMinutes = (((timer) % 3600 ) / 60) ;

if numberOfDays < 1 then		 
	numberOfHours =  math.floor(numberOfHours+0.0)
	numberOfMinutes =  math.floor(numberOfMinutes+0.0)
	_G[name]:SetText(numberOfHours .. " hrs " .. numberOfMinutes .. " mins")
 else
	if numberOfHours < 1 then
		numberOfDays =  math.floor(numberOfDays+0.0)
		numberOfHours =  math.floor(numberOfHours+0.0)
		numberOfMinutes =  math.floor(numberOfMinutes+0.0)
		_G[name]:SetText(numberOfDays .. " days " .. numberOfMinutes .. " mins")		
	else
		numberOfDays =  math.floor(numberOfDays+0.0)
		numberOfHours =  math.floor(numberOfHours+0.0)
		numberOfMinutes =  math.floor(numberOfMinutes+0.0)
		_G[name]:SetText(numberOfDays .. " days " .. numberOfHours .. " hrs")
	end
end

end
function Config:CheckForNoId()

	if  timerMC:GetText() == nil  or  timerMC:GetText() ~= "Yes" then
			timerMC:SetText("No")
			diff = difftime(ZishorRaidResetTimers[1], time())
			self:UpdateRaidTimersWithOutID("TimerMC", diff)
	end
	
	if  timerBWL:GetText() == nil  or timerBWL:GetText() ~= "Yes" then
			timerBWL:SetText("No")
			diff = difftime(ZishorRaidResetTimers[1], time())
			self:UpdateRaidTimersWithOutID("TimerBWL", diff)
	end
	
	if   timerZG:GetText() == nil  or  timerZG:GetText() ~= "Yes" then
			timerZG:SetText("No")
			diff = difftime(ZishorRaidResetTimers[3], time())
			self:UpdateRaidTimersWithOutID("TimerZG", diff)
	end
	
	if  timerOny:GetText() == nil  or timerOny:GetText() ~= "Yes" then
			timerOny:SetText("No")
			diff = difftime(ZishorRaidResetTimers[2], time())
			self:UpdateRaidTimersWithOutID("TimerOny", diff)
	end
	if  timerAQ20:GetText() == nil  or timerAQ20:GetText() ~= "Yes" then
			timerAQ20:SetText("No")
			diff = difftime(ZishorRaidResetTimers[3], time())
			self:UpdateRaidTimersWithOutID("TimerAQ20", diff)
	end
	if  timerAQ40:GetText() == nil  or timerAQ40:GetText() ~= "Yes" then
			timerAQ40:SetText("No")
			diff = difftime(ZishorRaidResetTimers[1], time())
			self:UpdateRaidTimersWithOutID("TimerAQ40", diff)
	end

end



function Config:NoIDsExisting()
	timerMC:SetText("No")
	timerOny:SetText("No")
	timerBWL:SetText("No")
	timerZG:SetText("No")
	timerAQ20:SetText("No")
	timerAQ40:SetText("No")
end

function Config:CreateButton(point, relativeFrame, relativePoint, yOffset, text)
	local btn = CreateFrame("Button", nil, UIConfig, "GameMenuButtonTemplate");
	btn:SetPoint(point, relativeFrame, relativePoint, 0, yOffset);
	btn:SetSize(140, 40);
	btn:SetText(text);
	btn:SetNormalFontObject("GameFontNormalLarge");
	btn:SetHighlightFontObject("GameFontHighlightLarge");
	return btn;
end
function Config:ResetToonsIDAutomaticly()


end
function Config:CreateMenu()

	UIConfig = CreateFrame("Frame", "ZishorRaidReset", UIParent, "UIPanelDialogTemplate");
	UIConfig:SetSize(350, 480);
	UIConfig:SetPoint("CENTER"); 

	--movable Frame
	UIConfig:SetMovable(true);
	UIConfig:EnableMouse(true);
	UIConfig:RegisterForDrag("LeftButton")
	UIConfig:SetScript("OnDragStart", UIConfig.StartMoving)
	UIConfig:SetScript("OnDragStop", UIConfig.StopMovingOrSizing)
	
	--set up the initial text
	
	INFOText = UIConfig:CreateFontString(nil, "OVERLAY", "GameFontDisable")
	INFOText:SetPoint("TOPLEFT", 20, -40)
	INFOText:SetText("Instance")
	
	INFOTextID = UIConfig:CreateFontString(nil, "OVERLAY", "GameFontDisable")
	INFOTextID:SetPoint("TOPLEFT", 120, -40)
	INFOTextID:SetText("ID")
	
	INFOTextNextAvailable = UIConfig:CreateFontString(nil, "OVERLAY", "GameFontDisable")
	INFOTextNextAvailable:SetPoint("TOPLEFT", 180, -40)
	INFOTextNextAvailable:SetText("Next Reset")
	
	MCText = UIConfig:CreateFontString(nil, "OVERLAY", "GameFontNormal")
	MCText:SetPoint("TOPLEFT", 20, -80)
	MCText:SetText("MC")
	
	timerMC = UIConfig:CreateFontString(nil, "MCTimer", "GameFontNormal")
	timerMC:SetPoint("TOPLEFT", 120, -80)
	
	nextAvailableMC = UIConfig:CreateFontString("TimerMC", "OVERLAY", "GameFontNormal")
	nextAvailableMC:SetPoint("TOPLEFT", 180, -80)
	
	ONYText = UIConfig:CreateFontString(nil, "OVERLAY", "GameFontNormal")
	ONYText:SetPoint("TOPLEFT", 20, -120)
	ONYText:SetText("Ony")
	
	timerOny = UIConfig:CreateFontString(nil, "OnyTimer", "GameFontNormal")
	timerOny:SetPoint("TOPLEFT", 120, -120)
	
	nextAvailableOny = UIConfig:CreateFontString("TimerOny", "OVERLAY", "GameFontNormal")
	nextAvailableOny:SetPoint("TOPLEFT", 180, -120)
	
	BWLText = UIConfig:CreateFontString(nil, "OVERLAY", "GameFontNormal")
	BWLText:SetPoint("TOPLEFT", 20, -160)
	BWLText:SetText("BWL")
	
	timerBWL = UIConfig:CreateFontString(nil, "BWLTimer", "GameFontNormal")
	timerBWL:SetPoint("TOPLEFT", 120, -160)
	
	nextAvailableBWL = UIConfig:CreateFontString("TimerBWL", "OVERLAY", "GameFontNormal")
	nextAvailableBWL:SetPoint("TOPLEFT", 180, -160)
	
	ZGText = UIConfig:CreateFontString(nil, "ZG", "GameFontNormal")
	ZGText:SetPoint("TOPLEFT", 20, -200)
	ZGText:SetText("ZG")
	
	timerZG = UIConfig:CreateFontString(nil, "ZGTimer", "GameFontNormal")
	timerZG:SetPoint("TOPLEFT", 120, -200)
	
	nextAvailableZG = UIConfig:CreateFontString("TimerZG", "OVERLAY", "GameFontNormal")
	nextAvailableZG:SetPoint("TOPLEFT", 180, -200)
	
	AQ20Text = UIConfig:CreateFontString(nil, "AQ20", "GameFontNormal")
	AQ20Text:SetPoint("TOPLEFT", 20, -240)
	AQ20Text:SetText("AQ20")
	
	timerAQ20 = UIConfig:CreateFontString(nil, "AQ20Timer", "GameFontNormal")
	timerAQ20:SetPoint("TOPLEFT", 120, -240)
	
	nextAvailableAQ20 = UIConfig:CreateFontString("TimerAQ20", "OVERLAY", "GameFontNormal")
	nextAvailableAQ20:SetPoint("TOPLEFT", 180, -240)
	
	AQ40Text = UIConfig:CreateFontString(nil, "AQ40", "GameFontNormal")
	AQ40Text:SetPoint("TOPLEFT", 20, -280)
	AQ40Text:SetText("AQ40")
	
	timerAQ40 = UIConfig:CreateFontString(nil, "AQ40Timer", "GameFontNormal")
	timerAQ40:SetPoint("TOPLEFT", 120, -280)
	
	nextAvailableAQ40 = UIConfig:CreateFontString("TimerAQ40", "OVERLAY", "GameFontNormal")
	nextAvailableAQ40:SetPoint("TOPLEFT", 180, -280)
	
	UIConfig.loadBtn = self:CreateButton("CENTER", UIConfig, "TOP", -380, "Alts");
		
	UIConfig.loadBtn:SetScript("OnClick", function(self, arg1)
		
	Config:setupToonsMenu(classIndex)	
		--print(date("%c",1589353200))
	end)
	
	
	UIConfig:Hide();
	return UIConfig;
end
local frame = CreateFrame("Frame")
frame:RegisterAllEvents()
frame:SetScript('OnEvent',
    function(self, event, arg1,  ...)
		if UIConfigToons ~= nil and UIConfigToons:IsShown() == false  and menu ~= nil and menu:IsShown() == false and bHelper then
			bHelper = false
			menu:SetShown(true)
		end
		if event == "PLAYER_LOGIN" then
			--Update DB with all IDs in it stored when reload is executed (doesnt work for login)
			menu = UIConfig or Config:CreateMenu();		
			Config:UpdateFrame();
			bLoginHelper = true;
			loginTime = time()
			
		end
		
		if (time() - loginTime) >= 5  and bLoginHelper then	
			--Update the timers a second time, because when you first login, you dont get the savedinstance information instantly
			Config:UpdateFrame();
			bLoginHelper = false;
			--Update ToonsID and reset if the reset was already
			--Config:ResetToonsIDAutomaticly();
		end
    end
)

function Config:setupToonsMenu(classIndex)
	
	if UIConfigToons == nil then
	
		if Config:getTableLength(ZishorToonRaidResetTimers) == 1 and ZishorToonRaidResetTimers[1].name == UnitName("player") or
			next(ZishorToonRaidResetTimers) == nil then
			UIConfigToons = CreateFrame("Frame", "ZishorRaidResetToons", UIParent, "UIPanelDialogTemplate");
			UIConfigToons:SetSize( 300 , 380);
			UIConfigToons:SetPoint("CENTER"); 
			
			NoToonsWithID = UIConfigToons:CreateFontString(nil, "ZG", "GameFontNormal")
			NoToonsWithID:SetPoint("Center")
			NoToonsWithID:SetText("You have no LVL 60 Alts with an ID \nor you haven't logged in with any yet.")
			
		else
		-- initial creating of the frame
		UIConfigToons = CreateFrame("Frame", "ZishorRaidResetToons", UIParent, "UIPanelDialogTemplate");
		UIConfigToons:SetSize( (110 + Config:getTableLength(ZishorToonRaidResetTimers) * 120 ) , 380);
		UIConfigToons:SetPoint("CENTER"); 

		MCTextAlts = UIConfigToons:CreateFontString(nil, "OVERLAY", "GameFontNormal")
		MCTextAlts:SetPoint("TOPLEFT", 20, -80)
		MCTextAlts:SetText("MC")
		
		OnyTextAlts = UIConfigToons:CreateFontString(nil, "OVERLAY", "GameFontNormal")
		OnyTextAlts:SetPoint("TOPLEFT", 20, -120)
		OnyTextAlts:SetText("Ony")
		
		BWLTextAlts = UIConfigToons:CreateFontString(nil, "OVERLAY", "GameFontNormal")
		BWLTextAlts:SetPoint("TOPLEFT", 20, -160)
		BWLTextAlts:SetText("BWL")
		
		ZGTextAlts = UIConfigToons:CreateFontString(nil, "ZG", "GameFontNormal")
		ZGTextAlts:SetPoint("TOPLEFT", 20, -200)
		ZGTextAlts:SetText("ZG")
		
		AQ20TextAlts = UIConfigToons:CreateFontString(nil, "AQ20", "GameFontNormal")
		AQ20TextAlts:SetPoint("TOPLEFT", 20, -240)
		AQ20TextAlts:SetText("AQ20")
		
		AQ40TextAlts = UIConfigToons:CreateFontString(nil, "AQ40", "GameFontNormal")
		AQ40TextAlts:SetPoint("TOPLEFT", 20, -280)
		AQ40TextAlts:SetText("AQ40")
		
		local location = 100
		firstEntry = false;
		for i = 1 ,Config:getTableLength(ZishorToonRaidResetTimers) do 
			if ZishorToonRaidResetTimers[i] ~= nil and ZishorToonRaidResetTimers[i].name ~= UnitName("player") then
				--setup all toons and display them with the name and classcolor
				length = string.len(ZishorToonRaidResetTimers[i].name)
				--now calculate the location depending on char name
				if firstEntry then location = location + string.len(ZishorToonRaidResetTimers[i-1].name) + 100  end
				--to have the same space everywhere we adapt the calculation
				--if i % 2 == 1 then location = location + 20 end
				local toon = Config:CreateToonFontStrings(i, length, location)
				firstEntry = true;
				--now check if the toon has ID
				--Now check if the chars have an ID or not
				for j = 1 , Config:getTableLength(ZishorToonRaidResetTimers[i].raidIDs) do
					local toonID = Config:CreateToonRaidFontStrings(location , j,  ZishorToonRaidResetTimers[i].raidIDs[j])
				end				
			end
		end
		--resize the frame after we know all character name length
		UIConfigToons:SetSize( 110 + location , 380);
		
		
		end
		
		UIConfigToons:SetMovable(true);
		UIConfigToons:EnableMouse(true);
		UIConfigToons:RegisterForDrag("LeftButton")
		UIConfigToons:SetScript("OnDragStart", UIConfigToons.StartMoving)
		UIConfigToons:SetScript("OnDragStop", UIConfigToons.StopMovingOrSizing)	
		menu:SetShown(false)
		UIConfigToons:SetShown(true)
	else
	menu:SetShown(false)
	UIConfigToons:SetShown(true)

	end
	bHelper = true;
	
end

function Config:CreateToonFontStrings(index, characterNameLength, location)
	local toonFontStrings = UIConfigToons:CreateFontString(nil, "OVERLAY", "GameFontDisable")
	toonFontStrings:SetPoint("TOPLEFT", location, -40)
	toonFontStrings:SetTextColor(classColors[ZishorToonRaidResetTimers[index].classID].r,classColors[ZishorToonRaidResetTimers[index].classID].g,classColors[ZishorToonRaidResetTimers[index].classID].b)
	toonFontStrings:SetText(ZishorToonRaidResetTimers[index].name)
	return toonFontStrings;
end

function Config:CreateToonRaidFontStrings(i, j,  text)
	local toonRaidFontStrings = UIConfigToons:CreateFontString(nil, "OVERLAY", "GameFontDisable")
	if j == 1 then toonRaidFontStrings:SetPoint("TOPLEFT", i, - 80) else  toonRaidFontStrings:SetPoint("TOPLEFT", i, (-40 - ( j * 40 )) )  end
	toonRaidFontStrings:SetText(text)
	return toonRaidFontStrings;
end

function Config:getTableLength(T)
  local count = 0
  for _ in pairs(T) do count = count + 1 end
  return count
end


local addon = LibStub("AceAddon-3.0"):NewAddon("ZishorRiadReset", "AceConsole-3.0")
local ZishorRiadResetLDB = LibStub("LibDataBroker-1.1"):NewDataObject("ZishorRiadReset!", {
    type = "data source",
    text = "ZishorRiadReset!",
    icon = "Interface\\Icons\\ability_dualwield",
	OnTooltipShow = function(tooltip)
          tooltip:SetText("Zishor Raid Reset")
          tooltip:AddLine("Left Hold: drag icon", 1, 2, 3)
		  tooltip:AddLine("Left/Right Click: open addon", 1, 2, 3)
          tooltip:Show()
     end,
    OnClick = function ()
	menu = UIConfig or Config:CreateMenu();
	Config:FrameUpdateHandler()
end
})
local icon = LibStub("LibDBIcon-1.0")
 
function addon:OnInitialize()
    self.db = LibStub("AceDB-3.0"):New("ZishorRaidResetDB", {
        profile = {
            minimap = {
                hide = false,
            },
        },
    })
    icon:Register("ZishorRiadReset!", ZishorRiadResetLDB, self.db.profile.minimap)
    
end

